package com.clx.performance.service.impl.thirdparty.nbbank;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.clx.performance.enums.PerformanceResultEnum;
import com.clx.performance.service.thirdparty.nbbank.NbBankService;
import com.clx.performance.service.thirdparty.nbbank.NbBankThirdpartyService;
import com.msl.common.exception.ServiceSystemException;
import com.nbopen.api.SDKResponse;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;

/**
 * 易付通
 */
@Slf4j
@Service
public class NbBankServiceImpl implements NbBankService {

    @Autowired
    private NbBankThirdpartyService bankThirdpartyService;

    /**
     * 订单支付
     * @return
     * 第三方流水号
     */
    @Override
    public String orderPay(Integer payType) {
        if (payType == 1){
            String merSeqNo = LocalDateTime.now().format(DateTimeFormatter.ofPattern("yyyyMMddHHmmss"));
            JSONObject data = bankThirdpartyService.directBankTransferOrder(merSeqNo);

            String transSeqNo = data.getString("transSeqNo");
            return transSeqNo;
        }
        else if (payType == 2){
            String merSeqNo = LocalDateTime.now().format(DateTimeFormatter.ofPattern("yyyyMMddHHmmss"));
            JSONObject data = bankThirdpartyService.unionPayDirectOrder(merSeqNo);

            String transSeqNo = data.getString("transSeqNo");
            return transSeqNo;
        }

        throw new ServiceSystemException(PerformanceResultEnum.NB_BANK_PAY_TYPE_ERROR);
    }

    /**
     * 获取交易状态
     * @return
     */
    @Override
    public Integer getOrderStatus(String merSeqNo) {
        SDKResponse sdkResponse = bankThirdpartyService.queryOrder(merSeqNo);

        JSONObject response = JSON.parseObject(JSON.toJSONString(sdkResponse));
        String transStatus = response.getString("transStatus");

        if (StringUtils.equals(transStatus, "00")){return 1;}       //交易成功
        if (StringUtils.equals(transStatus, "01")){return 2;}       //交易失败
        if (StringUtils.equals(transStatus, "02")){return 3;}       //交易已受理
        if (StringUtils.equals(transStatus, "80")){return 4;}       //订单初始状态
        if (StringUtils.equals(transStatus, "90")){return 5;}       //交易不存在
        if (StringUtils.equals(transStatus, "99")){return 6;}       //交易超时,须发起交易结果查询

        return 1;
    }

    @Override
    public void orderPayCallback(String merSeqNo, String transSeqNo, BigDecimal trxAmt, String transStatus) {
        log.info("宁波银行支付回调, merSeqNo:{}, transSeqNo:{}, transSeqNo:{}, transSeqNo:{}", merSeqNo, transSeqNo, trxAmt, transStatus);

        if (StringUtils.equals(transStatus, "00")){     //交易成功

        }
        if (StringUtils.equals(transStatus, "01")){     //交易失败

        }
        if (StringUtils.equals(transStatus, "02")){     //交易已受理

        }
        if (StringUtils.equals(transStatus, "80")){     //订单初始状态

        }
        if (StringUtils.equals(transStatus, "90")){     //交易不存在

        }
        if (StringUtils.equals(transStatus, "99")){     //交易超时,须发起交易结果查询

        }

    }

}
